## dbt-athena 1.9.2 - March 07, 2025

### Features

- Implement drop_glue_database macro and method ([#408](https://github.com/dbt-labs/dbt-adapters/issues/408))

### Under the Hood

- Issue a warning to dbt-athena-community users to migrate to dbt-athena ([#879](https://github.com/dbt-labs/dbt-adapters/issues/879))

### Contributors
- [@svdimchenko](https://github.com/svdimchenko) ([#408](https://github.com/dbt-labs/dbt-adapters/issues/408))
